@@ -26,7 +26,7 @@ from joblib import Parallel, delayed
 from canalyst_candas import settings
 from canalyst_candas.candas.func_music import FuncMusic
 from canalyst_candas.datafunctions import DataFunctions
-from canalyst_candas.configuration.config import Config
+from canalyst_candas.configuration.config import Config, create_config
 from canalyst_candas.exceptions import ScenarioException, CSINEmptyException
 from canalyst_candas.utils.logger import LogFile
 from canalyst_candas.utils.transformations import (
@@ -73,7 +73,7 @@ class ModelMap:
             Iterable
         ] = None,  # optional list of common features. nodes with this feature will be made triangles
     ) -> None:
-        self.config = config or settings.CONFIG
+        self.config = config or create_config()
         self.s3_client = Getter(config=self.config)
         self.api_headers: Dict[str, str] = get_api_headers(self.config.canalyst_api_key)
         self.log = LogFile()
@@ -478,7 +478,7 @@ class Model:
         file_type: str = "parquet",
     ):
         self.file_type = file_type
-        self.config = config or settings.CONFIG
+        self.config = config or create_config()
         self.ticker = ticker
         self.force = force
         self.company_info = company_info
