@@ -16,8 +16,7 @@ from canalyst_candas.datafunctions import DataFunctions
 from canalyst_candas.candas.model import Model
 from canalyst_candas.candas.chart import Chart
 from canalyst_candas.candas.func_music import FuncMusic
-from canalyst_candas.settings import CONFIG
-from canalyst_candas.configuration.config import Config
+from canalyst_candas.configuration.config import Config, create_config
 from canalyst_candas.exceptions import ScenarioException
 from canalyst_candas.utils.logger import LogFile
 from canalyst_candas.utils.transformations import (
@@ -51,7 +50,7 @@ class ModelSet:
         ticker_list: List[str],
         config: Config = None,
         extract_drivers: bool = True,
-        allow_nulls: bool = False,
+        allow_nulls: bool = True,
         company_info: bool = True,
         file_type: str = "parquet",
     ):
@@ -70,7 +69,7 @@ class ModelSet:
         """
         self.file_type = file_type
         self.allow_nulls = allow_nulls
-        self.config = config or CONFIG
+        self.config = config or create_config()
         self.extract_drivers = extract_drivers
         self.log = LogFile()
 
