@@ -435,7 +435,7 @@ def get_csin_from_ticker(
     return csin
 
 
-def get_excel_model(config, logger, ticker="", download_dir=""):
+def get_excel_model(config, ticker="", download_dir="", logger=None):
     """
     Retrieve Excel model from Web Portal
     """
@@ -647,7 +647,7 @@ def create_drivers_dot(
     path_name = f"DATA/{file_ticker}"
 
     if not config:
-        config = settings.CONFIG or resolve_config()
+        config = resolve_config()
     if not s3_client:
         s3_client = Getter(config)
 
@@ -811,7 +811,7 @@ def refresh_cache(
     TODO: possible unused function: delete if necessary
     """
     if not config:
-        config = settings.CONFIG or resolve_config()
+        config = resolve_config()
     if not log:
         log = LogFile(default_dir=config.default_dir)
     if not s3_client:
@@ -835,7 +835,7 @@ def get_candas_ticker_list(ticker="", config=None):
     ticker = ticker.split(" ")[0]
 
     if not config:
-        config = settings.CONFIG or resolve_config()
+        config = resolve_config()
 
     session = Session(
         aws_access_key_id=config.s3_access_key_id,
@@ -883,6 +883,10 @@ def get_forecast_period_name(
         forecast_endpoint, api_headers, logger, verify_ssl
     )
 
+    forecast_period_name = response_content["results"][0]["name"]
+
+    return forecast_period_name
+
 
 def get_sample_drivers(ticker: str):
     """
